BatteryInfo

Struct BatteryInfo 

pub struct BatteryInfo {
Show 15 fields pub status: Option<BatteryStatus>, pub charge_status: Option<ChargeStatus>, pub charge_source: Option<ChargeSource>, pub level_percent: Option<f32>, pub level_status: Option<LevelStatus>, pub health: Option<HealthStatus>, pub time_remaining: Option<TimeRemaining>, pub timestamp: Option<i64>, pub present_voltage_mv: Option<u32>, pub remaining_charge_uah: Option<u32>, pub battery_spec: Option<BatterySpec>, pub full_capacity_uah: Option<i32>, pub temperature_mc: Option<i32>, pub present_charging_current_ua: Option<i32>, pub average_charging_current_ua: Option<i32>, /* private fields */
}
Current battery state information.

Fields

status: Option<BatteryStatus>

General battery status with respect to presence & availability.

charge_status: Option<ChargeStatus>

The current state of the battery with respect to charging.

charge_source: Option<ChargeSource>

The current power source for the device.

A connected power source does not guarantee the battery is actively charging (for example, if the battery is full, does not need charging, or has a fault). See charge_status for the current charging state.

level_percent: Option<f32>

Battery level in percentage. Level percent is only available if level status is known.

level_status: Option<LevelStatus>

Battery level as a general status, including low and critical.

health: Option<HealthStatus>

Overall battery health.

time_remaining: Option<TimeRemaining>

Time remaining relative to the current charge status.

timestamp: Option<i64>

Marking the time for measurement of battery level.

present_voltage_mv: Option<u32>

Forward the voltage level in mv.

remaining_charge_uah: Option<u32>

The amount of electric charge currently stored in the battery, measured in µAh. This value decreases as the device is used and increases during charging.

battery_spec: Option<BatterySpec>

Battery spec.

full_capacity_uah: Option<i32>

Full Charge Capacity in uAh.

temperature_mc: Option<i32>

Temperature in MilliCelsius.

present_charging_current_ua: Option<i32>

Current in MicroAmps. Positive for charging.

average_charging_current_ua: Option<i32>

Average Current in MicroAmps. Positive for charging.